pm4py.algo.reduction.process\_tree package
==========================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.reduction.process_tree.variants

Submodules
----------

pm4py.algo.reduction.process\_tree.reducer module
-------------------------------------------------

.. automodule:: pm4py.algo.reduction.process_tree.reducer
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.reduction.process_tree
   :members:
   :undoc-members:
   :show-inheritance:
